rpms/ularn/devel config.sh.in, NONE, 1.1 ularn-build.patch, NONE, 1.1 ularn-datadir.patch, NONE, 1.1 ularn-drop-setgid.patch, NONE, 1.1 ularn-euid.patch, NONE, 1.1 ularn.desktop, NONE, 1.1 ularn.png, NONE, 1.1 ularn.spec, NONE, 1.1 .cvsignore, 1.1, 1.2 sources, 1.1, 1.2

Michael Thomas (wart) fedora-extras-commits at redhat.com
Fri Mar 17 18:12:24 UTC 2006


Author: wart

Update of /cvs/extras/rpms/ularn/devel
In directory cvs-int.fedora.redhat.com:/tmp/cvs-serv26575/devel

Modified Files:
	.cvsignore sources 
Added Files:
	config.sh.in ularn-build.patch ularn-datadir.patch 
	ularn-drop-setgid.patch ularn-euid.patch ularn.desktop 
	ularn.png ularn.spec 
Log Message:
auto-import ularn-1.5p4-4 on branch devel from ularn-1.5p4-4.src.rpm


--- NEW FILE config.sh.in ---
#!/bin/sh
# config.sh
# This file was produced by running the Configure script.

hpux='undef'
linux='define'
bsd='undef'
cygwin='undef'
syserr='define'
bsdlibs=''
d_eunice='undef'
eunicefix=':'
define='define'
contains='grep'
cppstdin='/usr/bin/cpp'
cppminus=''
d_ftime='define'
d_getopt='define'
d_index='define'
d_termio='define'
d_voidsig='define'
libc='/usr/lib/libc.a'
mansrc=''
manext=''
models='none'
split=''
small=''
medium=''
large=''
huge=''
ccflags=''
ldflags=''
cc='gcc'
n='-n'
c=''
package='Ularn'
spitshell='cat'
shsharp='true'
sharpbang='#!'
startsh='#!/bin/sh'
loclist='
expr
sed
echo
cat
rm
tr
grep
'
expr='/usr/bin/expr'
sed='/bin/sed'
echo='/bin/echo'
cat='/bin/cat'
rm='/bin/rm'
mv=''
cp=''
tail=''
tr='/usr/bin/tr'
mkdir=''
sort=''
uniq=''
grep='/bin/grep'
trylist='
xmkmf
imake
compress
uncompress
test
Mcc
cpp
'
test='test'
inews=''
egrep=''
more=''
pg=''
Mcc='Mcc'
vi=''
mailx=''
mail=''
cpp='@bindir@/cpp'
perl=''
compress='@bindir@/compress'
uncompress='@bindir@/uncompress'
imake='/usr/bin/X11/imake'
xmkmf='/usr/bin/X11/xmkmf'
bindir='@bindir@'
d_drand48='define'
d_havetlib='define'
termlib='-lcurses'
d_itimer='define'
d_systime='<sys/time.h>'
d_random='undef'
defcomp='undef'
imaketmpl=''
libdir='@datadir@/ularn'
scoredir='@var@/games'
mycompress='@bindir@/compress -c'
myuncompress='@bindir@/uncompress -c'
CONFIG=true

ularn-build.patch:

--- NEW FILE ularn-build.patch ---
diff -Naur Ularn/extern.h Ularn.new/extern.h
--- Ularn/extern.h	2001-11-16 10:13:18.000000000 -0800
+++ Ularn.new/extern.h	2006-02-25 16:34:40.000000000 -0800
@@ -88,11 +88,11 @@
 int getcharacter(void);
 int newgame(void);
 /*VARARGS*/
-int lprintf();
+int lprintf(char *, ...);
 int lprint(long);
 int lwrite(char *, int);
 long lgetc1(void);
-long lrint(void);
+long lr_int(void);
 int lrfill(char *, int);
 char *lgetw(void);
 char *lgetl(void);
@@ -441,11 +441,11 @@
 int getcharacter();
 int newgame();
 /*VARARGS*/
-int lprintf();
+int lprintf(char *, ...);
 int lprint();
 int lwrite();
 long lgetc1();
-long lrint();
+long lr_int();
 int lrfill();
 char *lgetw();
 char *lgetl();
diff -Naur Ularn/fortune.c Ularn.new/fortune.c
--- Ularn/fortune.c	2001-11-16 10:13:19.000000000 -0800
+++ Ularn.new/fortune.c	2006-02-25 16:21:57.000000000 -0800
@@ -16,7 +16,6 @@
 	int lines,tmp;
 	struct stat stat;
 	int retval;
-	char *malloc();
 
 	if (fortune_fd==0) {
 		/* open the file */
diff -Naur Ularn/header.h Ularn.new/header.h
--- Ularn/header.h	2001-11-16 10:13:19.000000000 -0800
+++ Ularn.new/header.h	2006-02-25 16:22:58.000000000 -0800
@@ -27,7 +27,8 @@
 #include <pwd.h>
 #include <signal.h>
 #include <stdio.h>
-#include <varargs.h>
+#include <stdlib.h>
+#include <stdarg.h>
 #ifdef USG
 #  include <strings.h>
 #else
diff -Naur Ularn/main.c Ularn.new/main.c
--- Ularn/main.c	2001-11-16 10:13:20.000000000 -0800
+++ Ularn.new/main.c	2006-02-25 16:33:25.000000000 -0800
@@ -46,7 +46,7 @@
 {
 	int i, hard;
 	char buf[BUFSIZ];
-	char *malloc(), *getenv(), *getlogin(), *ptr=0;
+	char *getenv(), *getlogin(), *ptr=0;
 	struct passwd *pwe,*getpwuid();
 	extern char *optarg;
 	extern int optind, opterr;
diff -Naur Ularn/Makefile.u.SH Ularn.new/Makefile.u.SH
--- Ularn/Makefile.u.SH	2001-11-16 10:18:27.000000000 -0800
+++ Ularn.new/Makefile.u.SH	2006-02-25 17:20:26.000000000 -0800
@@ -97,12 +97,12 @@
 
 ##########################################################################
 install: $(PROGRAM) $(LIBFILES)
-	if test ! -d $(LIBDIR) ; then mkdir -p $(LIBDIR) ; fi
-	-cp Umaps Ufortune Uhelp $(LIBDIR)
-	-chmod 644 $(LIBDIR)/Umaps $(LIBDIR)/Ufortune \
-		$(LIBDIR)/Uhelp
-	if test ! -d $(BINDIR) ; then mkdir -p $(BINDIR) ; fi
-	-cp $(PROGRAM) $(BINDIR)
+	if test ! -d $(DESTDIR)$(LIBDIR) ; then mkdir -p $(DESTDIR)$(LIBDIR) ; fi
+	-cp Umaps Ufortune Uhelp $(DESTDIR)$(LIBDIR)
+	-chmod 644 $(DESTDIR)$(LIBDIR)/Umaps $(DESTDIR)$(LIBDIR)/Ufortune \
+		$(DESTDIR)$(LIBDIR)/Uhelp
+	if test ! -d $(DESTDIR)$(BINDIR) ; then mkdir -p $(DESTDIR)$(BINDIR) ; fi
+	-cp $(PROGRAM) $(DESTDIR)$(BINDIR)
 
 
 lint:
diff -Naur Ularn/savelev.c Ularn.new/savelev.c
--- Ularn/savelev.c	2001-11-16 10:13:27.000000000 -0800
+++ Ularn.new/savelev.c	2006-02-25 17:19:14.000000000 -0800
@@ -6,14 +6,7 @@
 #include "monst.h"
 #include "extern.h"
 
-#ifdef CYGWIN
 #include <errno.h>
-#define SYSERRLISTDEFINED
-#endif
-
-#ifndef SYSERRLISTDEFINED
-extern char *sys_errlist[];
-#endif
 
 extern int errno;
 
@@ -216,11 +209,11 @@
 	unsigned int thesum, asum;
 	struct sphere *sp,*splast;
 	Saved_Level * storage;
-	char buf[1024], *tmp="/tmp/UtmpXXXXXX", *mkstemp(); 
+	char buf[1024], *tempfilename="/tmp/UtmpXXXXXX";
     	int fd;
 
 	if (compress) {
-		if ((tempfilename = mkstemp(tmp)) == NULL) {
+		if (fd = (mkstemp(tempfilename)) == -1) {
 			fprintf(stderr,"Can't create temp file to restore game\n");
 			perror("mkstemp");
 			nosignal=0;
@@ -241,6 +234,7 @@
 			unlink(tempfilename);
 			return;
 		}
+/*
 		if ((fd = open(tempfilename, O_RDONLY)) < 0) {
 			fprintf(stderr,"Can't open temp file to restore game\n");
 			perror("open");
@@ -249,6 +243,7 @@
 			died(-265);
 			return;
 		}
+*/
 	} else {
 		if ((fd = open(fname, O_RDONLY)) <= 0) {
 			fprintf(stderr,"Can't open file <%s> to restore game\n", 
@@ -454,7 +449,7 @@
 	ncalls++;
 	if ((nwrote = write(fd, buf, num)) == -1) {
 		fprintf(stderr, "Error writing to save file\n");
-		fprintf(stderr, "errno = %d\t[%s]\n",errno,sys_errlist[errno]);
+		fprintf(stderr, "errno = %d\t[%s]\n",errno,strerror(errno));
 		fprintf(stderr, "    Wrote %d bytes so far\n", w);
 		fprintf(stderr, "        Call: %d\n", ncalls);
 		abort();
@@ -485,7 +480,7 @@
 	ncalls++;
 	if ((nread = read(fd, buf, num)) == -1) {
 		fprintf(stderr, "Error reading from save file\n");
-		fprintf(stderr, "errno = %d\t[%s]\n",errno,sys_errlist[errno]);
+		fprintf(stderr, "errno = %d\t[%s]\n",errno,strerror(errno));
 		fprintf(stderr, "    Read %d bytes so far\n", w);
 		fprintf(stderr, "        Call: %d\n", ncalls);
 		perror("read");
diff -Naur Ularn/tok.c Ularn.new/tok.c
--- Ularn/tok.c	2001-11-16 10:13:31.000000000 -0800
+++ Ularn.new/tok.c	2006-02-25 17:07:40.000000000 -0800
@@ -3,6 +3,7 @@
 #include "player.h"
 #include "monst.h"
 #include "extern.h"
+#include <unistd.h>
 extern int nonap;
 
 #define MAXUM 52	/* maximum number of user re-named monsters */
@@ -61,11 +62,15 @@
 		/* shell escape */
 		if (cc == '!')	{
 			int pgrp;
+/*
 #ifdef USG
+*/
 			pgrp = getpgrp();
+/*
 #else
 			pgrp = getpgrp(getpid());
-#endif /* USG */
+#endif
+*/
 			
 			resetscroll();
 			clear();
@@ -75,7 +80,7 @@
 				settty();
 				setuid(geteuid());
 				setgid(getegid());
-				setpgrp(getpid(), pgrp);
+				setpgid(getpid(), pgrp);
 				if ((sh = getenv("SHELL")) != (char *)NULL) {
 					execl(sh, sh, (char *)0);	
 					if (!strcmp(sh, "/bin/sh")) {

ularn-datadir.patch:

--- NEW FILE ularn-datadir.patch ---
diff -Naur Ularn/config.h.SH Ularn.new/config.h.SH
--- Ularn/config.h.SH	2001-11-16 10:13:15.000000000 -0800
+++ Ularn.new/config.h.SH	2006-03-16 12:54:35.000000000 -0800
@@ -136,6 +136,11 @@
  */
 #define LIBDIR "$libdir"          /**/
 
+/* SCOREBOARDDIR:
+ *     This symbol indicates the directory containing the scoreboard file.
+ */
+#define SCOREBOARDDIR "$scoredir"          /**/
+
 /* COMPRESS
  *  This symbol contains the command to do compression from stdin
  *  to stdout.
diff -Naur Ularn/data.c Ularn.new/data.c
--- Ularn/data.c	2001-11-16 10:48:22.000000000 -0800
+++ Ularn.new/data.c	2006-03-16 13:00:30.000000000 -0800
@@ -4,6 +4,7 @@
 #include "itm.h"
 
 char *libdir = LIBDIR;
+char *scoredir = SCOREBOARDDIR;
 
 /* the game save filename   */
 char savefilename[MAXPATHLEN];
diff -Naur Ularn/extern.h Ularn.new/extern.h
--- Ularn/extern.h	2006-03-16 07:58:03.000000000 -0800
+++ Ularn.new/extern.h	2006-03-16 13:14:37.000000000 -0800
@@ -712,7 +712,7 @@
 
 	/************** extern decls for all data items **********/
 
-extern char *tempfilename, *libdir;
+extern char *tempfilename, *libdir, *scoredir;
 extern char bot1f,bot2f,bot3f;	/* in display.c */
 extern char ckpfile[], monstnamelist[];
 extern char larnlevels[],lastmonst[];
diff -Naur Ularn/header.h Ularn.new/header.h
--- Ularn/header.h	2006-03-16 07:58:03.000000000 -0800
+++ Ularn.new/header.h	2006-03-16 13:21:29.000000000 -0800
@@ -47,7 +47,7 @@
 
 	/**************** File Names ****************/
 
-#define SCORENAME   "Uscore"
+#define SCORENAME   "Ularn-scoreboard"
 #define HELPNAME    "Uhelp"
 #define LEVELSNAME  "Umaps"
 #define FORTSNAME   "Ufortune"
diff -Naur Ularn/main.c Ularn.new/main.c
--- Ularn/main.c	2006-03-16 12:50:33.000000000 -0800
+++ Ularn.new/main.c	2006-03-16 13:17:19.000000000 -0800
@@ -95,7 +95,7 @@
 	sprintf(buf, "%s/%s", ptr, ckpfile);	/* the checkpoint file */
 	strcpy(ckpfile, buf);
 
-	sprintf(scorefile, "%s/%s", libdir, SCORENAME); /* the Ularn scoreboard filename */
+	sprintf(scorefile, "%s/%s", scoredir, SCORENAME); /* the Ularn scoreboard filename */
 
 	sprintf(helpfile, "%s/%s", libdir, HELPNAME); 	/* the Ularn on-line help file */
 
@@ -118,8 +118,9 @@
  */
 	if (access(scorefile,0) == -1) /* not there */
 		if (makeboard() == -1) {
-			fprintf(stderr, "I can't create the scoreboard.\n");
-			fprintf(stderr, "Check permissions on %s\n",libdir);
+			fprintf(stderr, "I can't create the scoreboard %s.\n",
+                                scorefile);
+			fprintf(stderr, "Check permissions on %s\n",scoredir);
 			exit(1);
 		}
 	

ularn-drop-setgid.patch:

--- NEW FILE ularn-drop-setgid.patch ---
diff -Naur Ularn/data.c Ularn.new/data.c
--- Ularn/data.c	2006-03-16 13:40:53.000000000 -0800
+++ Ularn.new/data.c	2006-03-16 13:39:41.000000000 -0800
@@ -5,6 +5,7 @@
 
 char *libdir = LIBDIR;
 char *scoredir = SCOREBOARDDIR;
+FILE *scoreboard_filehandle = (FILE *)NULL;
 
 /* the game save filename   */
 char savefilename[MAXPATHLEN];
diff -Naur Ularn/extern.h Ularn.new/extern.h
--- Ularn/extern.h	2006-03-16 13:40:53.000000000 -0800
+++ Ularn.new/extern.h	2006-03-16 13:42:26.000000000 -0800
@@ -713,6 +713,7 @@
 	/************** extern decls for all data items **********/
 
 extern char *tempfilename, *libdir, *scoredir;
+extern FILE *scoreboard_filehandle;
 extern char bot1f,bot2f,bot3f;	/* in display.c */
 extern char ckpfile[], monstnamelist[];
 extern char larnlevels[],lastmonst[];
diff -Naur Ularn/header.h Ularn.new/header.h
--- Ularn/header.h	2006-03-16 13:40:53.000000000 -0800
+++ Ularn.new/header.h	2006-03-17 07:02:33.000000000 -0800
@@ -6,6 +6,9 @@
 #include <sys/param.h>
 #include <sys/times.h>
 
+#define _GNU_SOURCE /* this must be done before the first include of unistd.h */
+#include <unistd.h>
+
 #ifdef FTIMER
 #  include <sys/timeb.h>
 #endif /* FTIMER */
diff -Naur Ularn/main.c Ularn.new/main.c
--- Ularn/main.c	2006-03-16 13:40:53.000000000 -0800
+++ Ularn.new/main.c	2006-03-17 07:02:35.000000000 -0800
@@ -50,7 +50,22 @@
 	struct passwd *pwe,*getpwuid();
 	extern char *optarg;
 	extern int optind, opterr;
+        gid_t realgid;
 
+        /* Open the scoreboard file immediately and then drop our setgid
+         * privileges.
+         */
+	sprintf(scorefile, "%s/%s", scoredir, SCORENAME); /* the Ularn scoreboard filename */
+        /* This could be NULL!  Users of this variable must check
+         * before using and not bother writing a scoreboard if it is null.
+         */
+        scoreboard_filehandle=fopen(scorefile, "r+");
+        realgid = getgid();
+        if (setresgid(-1, realgid, realgid) != 0) {
+            perror("Could not drop setgid privileges.  Aborting.");
+            exit(1);
+        }
+        
 
 /*
  *	first task is to identify the player
@@ -95,7 +110,6 @@
 	sprintf(buf, "%s/%s", ptr, ckpfile);	/* the checkpoint file */
 	strcpy(ckpfile, buf);
 
-	sprintf(scorefile, "%s/%s", scoredir, SCORENAME); /* the Ularn scoreboard filename */
 
 	sprintf(helpfile, "%s/%s", libdir, HELPNAME); 	/* the Ularn on-line help file */
 
diff -Naur Ularn/scores.c Ularn.new/scores.c
--- Ularn/scores.c	2001-11-16 10:13:28.000000000 -0800
+++ Ularn.new/scores.c	2006-03-16 14:22:14.000000000 -0800
@@ -145,8 +145,9 @@
 writeboard()
 {
 	FILE *fp;
+        fp = scoreboard_filehandle;
 
-	if ((fp = fopen(scorefile, "w")) == (FILE *)NULL) {
+	if (fp == (FILE *)NULL) {
 		lprcat("Can't open scorefile for writing\n"); 
 		lflush();
 		return(-1); 
@@ -185,7 +186,7 @@
 	}
 	if (writeboard()) 
 		return(-1);
-	chmod(scorefile, 0666);
+	//chmod(scorefile, 0666);
 	return(0);
 }
 

ularn-euid.patch:

--- NEW FILE ularn-euid.patch ---
diff -Naur Ularn/main.c Ularn.new/main.c
--- Ularn/main.c	2006-03-16 07:58:03.000000000 -0800
+++ Ularn.new/main.c	2006-03-16 12:37:51.000000000 -0800
@@ -55,15 +55,13 @@
 /*
  *	first task is to identify the player
  */
-	if ((ptr = getlogin()) == (char *)NULL) {
-	  	if (pwe=getpwuid(geteuid()))
-			ptr = pwe->pw_name;
-	  	else if ((ptr = getenv("LOGNAME")) == (char *)NULL)
-	  	if ((ptr = getenv("USER")) == (char *)NULL) {
-noone:		    	fprintf(stderr,"Who *are* you?\n");
-			exit(1);
-		 }
-	}
+       if (pwe=getpwuid(geteuid()))
+               ptr = pwe->pw_name;
+       else if ((ptr = getenv("LOGNAME")) == (char *)NULL)
+       if ((ptr = getenv("USER")) == (char *)NULL) {
+noone:	    	fprintf(stderr,"Who *are* you?\n");
+               exit(1);
+        }
 	if (ptr==(char *)NULL)
 		goto noone;
 	if (strlen(ptr)==0)


--- NEW FILE ularn.desktop ---
[Desktop Entry]
Encoding=UTF-8
Name=Ularn
GenericName=Ularn
Comment=Text based game
Exec=Ularn
Icon=ularn.png
Terminal=true
Type=Application
Categories=Application;Game;
Version=1.5p4


--- NEW FILE ularn.spec ---
Name:           ularn
Version:        1.5p4
Release:        4%{?dist}
Summary:        Simple roguelike game

Group:          Amusements/Games
License:        GPL
URL:            http://www.ularn.org
Source0:        http://www.ularn.org/Ularn-1.5ishPL4.tar.gz
Source1:        config.sh.in
Source2:        ularn.desktop
Source3:        ularn.png
Patch0:         ularn-build.patch
Patch1:         ularn-euid.patch
Patch2:         ularn-datadir.patch
Patch3:         ularn-drop-setgid.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  ncurses
BuildRequires:  desktop-file-utils
Requires:       ncompress

%description
A text-based roguelike game based on the original Larn.  Travel through
dungeons collecting weapons, killing monsters, in order to find and sell the
Eye of Larn to save your sick daughter.

%prep
%setup -q -n Ularn

# The configure script for this package is interactive.  However, it
# produces a config.sh script that can be customized if necessary.
# a pre-built config.sh script is used to avoid running an interactive
# configure script, but still must be customized slightly.
sed -e 's#@bindir@#%{_bindir}#' \
        -e 's#@datadir@#%{_datadir}#' \
        -e 's#@var@#%{_var}#' < %{SOURCE1} > config.sh
chmod +x config.h.SH
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
# Keep track of where we are.  Some of the configuration scripts change
# the current working directory.
builddir=`pwd`
. config.h.SH
${builddir}/Makefile.u.SH
cd ${builddir}
mv Makefile.u Makefile
CC="gcc $RPM_OPT_FLAGS" make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/%{_var}/games
touch $RPM_BUILD_ROOT/%{_var}/games/Ularn-scoreboard

desktop-file-install --vendor fedora                            \
        --dir ${RPM_BUILD_ROOT}%{_datadir}/applications         \
        --add-category X-Fedora                                 \
        %{SOURCE2}
mkdir -p $RPM_BUILD_ROOT/%{_datadir}/icons/hicolor/32x32/apps/
install -p -m 644 %{SOURCE3} $RPM_BUILD_ROOT/%{_datadir}/icons/hicolor/32x32/apps/

%clean
rm -rf $RPM_BUILD_ROOT

%post
touch --no-create %{_datadir}/icons/hicolor || :
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
   %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi

%postun
touch --no-create %{_datadir}/icons/hicolor || :
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
   %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi


# Note that the game is setgid games, and the directory with
# the score file is group writable.
%files
%defattr(-,root,root,-)
%attr(2755,root,games) %{_bindir}/Ularn
%{_datadir}/%{name}
%config(noreplace) %attr (0664,root,games) %{_var}/games/Ularn-scoreboard
%{_datadir}/applications/fedora-%{name}.desktop
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
%doc README README.spoilers GPL CHANGES.text Ularnopts


%changelog
* Fri Mar 17 2006 Wart <wart at kobold.org> 1.5p4-4
- Updated setgid patch to prevent someone from regaining setgid
  privileges.
- Own /usr/share/ularn directory

* Thu Mar 16 2006 Wart <wart at kobold.org> 1.5p4-3
- Added a patch to use the effective uid in determining the players name,
  or more precisely, don't use the id of the controlling terminal's user.
- Added a patch to look for game files in /usr/share/ularn and move the
  scoreboard to /var/games.
- Added a patch to drop setgid privileges after opening the scoreboard file
  for writing.

* Mon Mar 13 2006 Wart <wart at kobold.org> 1.5p4-2
- Added icon for .desktop file.
- Change default permissions so that only critical files are owned by 'games'
- Add missing scoreboard file.

* Sat Feb 25 2006 Wart <wart at kobold.org> 1.5p4-1
- Initial spec file.


Index: .cvsignore
===================================================================
RCS file: /cvs/extras/rpms/ularn/devel/.cvsignore,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- .cvsignore	17 Mar 2006 18:10:33 -0000	1.1
+++ .cvsignore	17 Mar 2006 18:12:24 -0000	1.2
@@ -0,0 +1 @@
+Ularn-1.5ishPL4.tar.gz


Index: sources
===================================================================
RCS file: /cvs/extras/rpms/ularn/devel/sources,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- sources	17 Mar 2006 18:10:33 -0000	1.1
+++ sources	17 Mar 2006 18:12:24 -0000	1.2
@@ -0,0 +1 @@
+e38861b422d4f8973536da0e8f475221  Ularn-1.5ishPL4.tar.gz




More information about the fedora-extras-commits mailing list
diff -Naur Ularn/io.c Ularn.new/io.c
--- Ularn/io.c	2001-11-16 10:13:19.000000000 -0800
+++ Ularn.new/io.c	2006-02-25 20:02:55.000000000 -0800
@@ -19,7 +19,7 @@
  *	FILE INPUT ROUTINES
  *
  *	long lgetc()			read one character from input buffer
  *	long lrint()			read one integer from input buffer
  *	lrfill(address,number)		put input bytes into a buffer
  *	char *lgetw()			get a whitespace ended word from input
  *	char *lgetl()			get a \n or EOF ended line from input
@@ -101,18 +101,14 @@
  */
 /*VARARGS*/
 
-lprintf(va_alist)
-va_dcl
+lprintf(char *fmt, ...)
 {
 	va_list ap;	/* pointer for variable argument list */
-	char *fmt;
 	char *outb,*tmpb;
 	long wide,left,cont,n;		/* data for lprintf	*/
 	char db[12];			/* %d buffer in lprintf	*/
 
-	va_start(ap);	/* initialize the var args pointer */
-
-	fmt = (char *)va_arg(ap, char *);	/* pointer to format string */
+	va_start(ap, fmt);	/* initialize the var args pointer */
 
 	if (lpnt >= lpend) lflush();
 	outb = lpnt;
@@ -308,7 +304,7 @@
 }
 
 /*
  *	long lrint()			Read one integer from input buffer
  *
  *		+---------+---------+---------+---------+
  *		|  high   |	    |	      |   low   |
@@ -320,7 +316,7 @@
  *	The save order is low order first, to high order (4 bytes total)
  *	Returns the int read
  */
-long lrint()
+long lr_int()
 {
 	long i;
 
@@ -562,7 +558,7 @@
 {
 	char termbuf[1024];
 	char *pc, *capptr = cap+10;
-	char *malloc(), *tgetstr(), *term, *getenv();
+	char *tgetstr(), *term, *getenv();
 
 	switch (tgetent(termbuf, term = getenv("TERM"))) {
 	case -1:
@@ -19,7 +19,7 @@
  *
  *	long lgetc()			read one character from input buffer
- *	long lrint()			read one integer from input buffer
+ *	long lr_int()			read one integer from input buffer
  *	lrfill(address,number)		put input bytes into a buffer
  *	char *lgetw()			get a whitespace ended word from input
@@ -308,7 +304,7 @@
 
 /*
- *	long lrint()			Read one integer from input buffer
+ *	long lr_int()			Read one integer from input buffer
  *
  *		+---------+---------+---------+---------+